@@ -20,10 +20,10 @@ class Directive(object):
     )
 
     def __init__(self, text):
-        """Initialize the directive by parsing the text.
+        r"""Initialize the directive by parsing the text.
 
         The text is assumed to be everything after a '#\s*' on a result line.
-        """  # noqa: flake8 is grumbling about the \s in the description.
+        """
         self._text = text
         self._skip = False
         self._todo = False
