@@ -96,7 +96,7 @@ class Result(Line):
         """
         if LOAD_YAML and self._yaml_block is not None:
             try:
-                yaml_dict = yaml.load(self._yaml_block)
+                yaml_dict = yaml.load(self._yaml_block, Loader=yaml.SafeLoader)
                 return yaml_dict
             except yaml.error.YAMLError:
                 print("Error parsing yaml block. Check formatting.")
