@@ -1,4 +1,4 @@
-# Copyright (c) 2018, Matt Layman and contributors
+# Copyright (c) 2019, Matt Layman and contributors
 
 import sys
 import tempfile
@@ -11,22 +11,20 @@ from tap.line import Bail, Plan, Result
 class Factory(object):
     """A factory to produce commonly needed objects"""
 
-    def make_ok(self, directive_text=''):
-        return Result(
-            True, 1, 'This is a description.', Directive(directive_text))
+    def make_ok(self, directive_text=""):
+        return Result(True, 1, "This is a description.", Directive(directive_text))
 
-    def make_not_ok(self, directive_text=''):
-        return Result(
-            False, 1, 'This is a description.', Directive(directive_text))
+    def make_not_ok(self, directive_text=""):
+        return Result(False, 1, "This is a description.", Directive(directive_text))
 
-    def make_bail(self, reason='Because it is busted.'):
+    def make_bail(self, reason="Because it is busted."):
         return Bail(reason)
 
-    def make_plan(self, expected_tests=99, directive_text=''):
+    def make_plan(self, expected_tests=99, directive_text=""):
         return Plan(expected_tests, Directive(directive_text))
 
     def make_test_result(self):
-        stream = tempfile.TemporaryFile(mode='w')
+        stream = tempfile.TemporaryFile(mode="w")
         return TextTestResult(stream, None, 1)
 
     def make_exc(self):
@@ -35,6 +33,6 @@ class Factory(object):
         Doing this intentionally is not straight forward.
         """
         try:
-            raise ValueError('boom')
+            raise ValueError("boom")
         except ValueError:
             return sys.exc_info()
