@@ -1,4 +1,4 @@
-# Copyright (c) 2018, Matt Layman and contributors
+# Copyright (c) 2019, Matt Layman and contributors
 
 import unittest
 
@@ -9,39 +9,39 @@ class TestDirective(unittest.TestCase):
     """Tests for tap.directive.Directive"""
 
     def test_finds_todo(self):
-        text = 'ToDo This is something to do.'
+        text = "ToDo This is something to do."
         directive = Directive(text)
 
         self.assertTrue(directive.todo)
 
     def test_finds_simplest_todo(self):
-        text = 'TODO'
+        text = "TODO"
         directive = Directive(text)
 
         self.assertTrue(directive.todo)
 
     def test_todo_has_boundary(self):
         """TAP spec indicates TODO directives must be on a boundary."""
-        text = 'TODO: Not a TODO directive because of an immediate colon.'
+        text = "TODO: Not a TODO directive because of an immediate colon."
         directive = Directive(text)
 
         self.assertFalse(directive.todo)
 
     def test_finds_skip(self):
-        text = 'Skipping This is something to skip.'
+        text = "Skipping This is something to skip."
         directive = Directive(text)
 
         self.assertTrue(directive.skip)
 
     def test_finds_simplest_skip(self):
-        text = 'SKIP'
+        text = "SKIP"
         directive = Directive(text)
 
         self.assertTrue(directive.skip)
 
     def test_skip_at_beginning(self):
         """Only match SKIP directives at the beginning."""
-        text = 'This is not something to skip.'
+        text = "This is not something to skip."
         directive = Directive(text)
 
         self.assertFalse(directive.skip)
