@@ -1,4 +1,4 @@
-# Copyright (c) 2018, Matt Layman and contributors
+# Copyright (c) 2019, Matt Layman and contributors
 
 import unittest
 
@@ -20,29 +20,25 @@ class TestResult(unittest.TestCase):
 
     def test_category(self):
         result = Result(True)
-        self.assertEqual('test', result.category)
+        self.assertEqual("test", result.category)
 
     def test_ok(self):
         result = Result(True)
         self.assertTrue(result.ok)
 
     def test_str_ok(self):
-        result = Result(True, 42, 'passing')
-        self.assertEqual(
-            'ok 42 passing', str(result))
+        result = Result(True, 42, "passing")
+        self.assertEqual("ok 42 passing", str(result))
 
     def test_str_not_ok(self):
-        result = Result(False, 43, 'failing')
-        self.assertEqual(
-            'not ok 43 failing', str(result))
+        result = Result(False, 43, "failing")
+        self.assertEqual("not ok 43 failing", str(result))
 
     def test_str_directive(self):
-        directive = Directive('SKIP a reason')
-        result = Result(True, 44, 'passing', directive)
-        self.assertEqual(
-            'ok 44 passing # SKIP a reason', str(result))
+        directive = Directive("SKIP a reason")
+        result = Result(True, 44, "passing", directive)
+        self.assertEqual("ok 44 passing # SKIP a reason", str(result))
 
     def test_str_diagnostics(self):
-        result = Result(False, 43, 'failing', diagnostics='# more info')
-        self.assertEqual(
-            'not ok 43 failing\n# more info', str(result))
+        result = Result(False, 43, "failing", diagnostics="# more info")
+        self.assertEqual("not ok 43 failing\n# more info", str(result))
