@@ -6,11 +6,7 @@ from io import BytesIO, StringIO
 import sys
 import tempfile
 import unittest
-
-try:
-    from unittest import mock
-except ImportError:
-    import mock
+from unittest import mock
 
 from tap.parser import Parser
 
