@@ -1,4 +1,4 @@
-# Copyright (c) 2018, Matt Layman and contributors
+# Copyright (c) 2019, Matt Layman and contributors
 
 import unittest
 
@@ -12,17 +12,16 @@ class TestRules(TestCase):
 
     def _make_one(self):
         self.suite = unittest.TestSuite()
-        return Rules('foobar.tap', self.suite)
+        return Rules("foobar.tap", self.suite)
 
     def test_handles_skipping_plan(self):
-        skip_plan = self.factory.make_plan(directive_text='Skip on Mondays.')
+        skip_plan = self.factory.make_plan(directive_text="Skip on Mondays.")
         rules = self._make_one()
 
         rules.handle_skipping_plan(skip_plan)
 
         self.assertEqual(1, len(self.suite._tests))
-        self.assertEqual(
-            'Skip on Mondays.', self.suite._tests[0]._line.description)
+        self.assertEqual("Skip on Mondays.", self.suite._tests[0]._line.description)
 
     def test_tracks_plan_line(self):
         plan = self.factory.make_plan()
@@ -30,8 +29,8 @@ class TestRules(TestCase):
 
         rules.saw_plan(plan, 28)
 
-        self.assertEqual(rules._lines_seen['plan'][0][0], plan)
-        self.assertEqual(rules._lines_seen['plan'][0][1], 28)
+        self.assertEqual(rules._lines_seen["plan"][0][0], plan)
+        self.assertEqual(rules._lines_seen["plan"][0][1], 28)
 
     def test_errors_plan_not_at_end(self):
         plan = self.factory.make_plan()
@@ -41,16 +40,16 @@ class TestRules(TestCase):
         rules.check(42)
 
         self.assertEqual(
-            _('A plan must appear at the beginning or end of the file.'),
-            self.suite._tests[0]._line.description)
+            _("A plan must appear at the beginning or end of the file."),
+            self.suite._tests[0]._line.description,
+        )
 
     def test_requires_plan(self):
         rules = self._make_one()
 
         rules.check(42)
 
-        self.assertEqual(
-            _('Missing a plan.'), self.suite._tests[0]._line.description)
+        self.assertEqual(_("Missing a plan."), self.suite._tests[0]._line.description)
 
     def test_only_one_plan(self):
         plan = self.factory.make_plan()
@@ -61,8 +60,9 @@ class TestRules(TestCase):
         rules.check(42)
 
         self.assertEqual(
-            _('Only one plan line is permitted per file.'),
-            self.suite._tests[0]._line.description)
+            _("Only one plan line is permitted per file."),
+            self.suite._tests[0]._line.description,
+        )
 
     def test_plan_line_two(self):
         """A plan may appear on line 2 when line 1 is a version line."""
@@ -82,18 +82,20 @@ class TestRules(TestCase):
         rules.check(2)
 
         self.assertEqual(
-            _('Expected {expected_count} tests but only '
-              '{seen_count} ran.').format(expected_count=42, seen_count=1),
-            self.suite._tests[0]._line.description)
+            _("Expected {expected_count} tests but only {seen_count} ran.").format(
+                expected_count=42, seen_count=1
+            ),
+            self.suite._tests[0]._line.description,
+        )
 
     def test_errors_on_bail(self):
-        bail = self.factory.make_bail(reason='Missing something important.')
+        bail = self.factory.make_bail(reason="Missing something important.")
         rules = self._make_one()
 
         rules.handle_bail(bail)
 
         self.assertEqual(1, len(self.suite._tests))
         self.assertEqual(
-            _('Bailed: {reason}').format(
-                reason='Missing something important.'),
-            self.suite._tests[0]._line.description)
+            _("Bailed: {reason}").format(reason="Missing something important."),
+            self.suite._tests[0]._line.description,
+        )
