@@ -1,4 +1,4 @@
-# Copyright (c) 2018, Matt Layman and contributors
+# Copyright (c) 2019, Matt Layman and contributors
 
 import unittest
 
@@ -6,7 +6,6 @@ from tap.tests.factory import Factory
 
 
 class TestCase(unittest.TestCase):
-
-    def __init__(self, methodName='runTest'):
+    def __init__(self, methodName="runTest"):
         super(TestCase, self).__init__(methodName)
         self.factory = Factory()
